@@ -2,12 +2,13 @@
 -- Copyright © 2012-2016  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
-
-module Codec.Encryption.OpenPGP.Types (module X) where
+module Codec.Encryption.OpenPGP.Types
+  ( module X
+  ) where
 
 import Codec.Encryption.OpenPGP.Types.Internal.Base as X
 import Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes as X
-import Codec.Encryption.OpenPGP.Types.Internal.PacketClass as X
 import Codec.Encryption.OpenPGP.Types.Internal.PKITypes as X
+import Codec.Encryption.OpenPGP.Types.Internal.PacketClass as X
 import Codec.Encryption.OpenPGP.Types.Internal.Pkt as X
 import Codec.Encryption.OpenPGP.Types.Internal.TK as X
